;;inc2scm extracted #define values from /usr/include/X11/keysym.h
;;inc2scm extracted #define values from /usr/include/X11/keysymdef.h
(define XK:VoidSymbol 16777215)
(define XK:BackSpace 65288)
(define XK:Tab 65289)
(define XK:Linefeed 65290)
(define XK:Clear 65291)
(define XK:Return 65293)
(define XK:Pause 65299)
(define XK:Scroll-Lock 65300)
(define XK:Sys-Req 65301)
(define XK:Escape 65307)
(define XK:Delete 65535)
(define XK:Multi-key 65312)
(define XK:Codeinput 65335)
(define XK:SingleCandidate 65340)
(define XK:MultipleCandidate 65341)
(define XK:PreviousCandidate 65342)
(define XK:Kanji 65313)
(define XK:Muhenkan 65314)
(define XK:Henkan-Mode 65315)
(define XK:Henkan 65315)
(define XK:Romaji 65316)
(define XK:Hiragana 65317)
(define XK:Katakana 65318)
(define XK:Hiragana-Katakana 65319)
(define XK:Zenkaku 65320)
(define XK:Hankaku 65321)
(define XK:Zenkaku-Hankaku 65322)
(define XK:Touroku 65323)
(define XK:Massyo 65324)
(define XK:Kana-Lock 65325)
(define XK:Kana-Shift 65326)
(define XK:Eisu-Shift 65327)
(define XK:Eisu-toggle 65328)
(define XK:Kanji-Bangou 65335)
(define XK:Zen-Koho 65341)
(define XK:Mae-Koho 65342)
(define XK:Home 65360)
(define XK:Left 65361)
(define XK:Up 65362)
(define XK:Right 65363)
(define XK:Down 65364)
(define XK:Prior 65365)
(define XK:Page-Up 65365)
(define XK:Next 65366)
(define XK:Page-Down 65366)
(define XK:End 65367)
(define XK:Begin 65368)
(define XK:Select 65376)
(define XK:Print 65377)
(define XK:Execute 65378)
(define XK:Insert 65379)
(define XK:Undo 65381)
(define XK:Redo 65382)
(define XK:Menu 65383)
(define XK:Find 65384)
(define XK:Cancel 65385)
(define XK:Help 65386)
(define XK:Break 65387)
(define XK:Mode-switch 65406)
(define XK:script-switch 65406)
(define XK:Num-Lock 65407)
(define XK:KP-Space 65408)
(define XK:KP-Tab 65417)
(define XK:KP-Enter 65421)
(define XK:KP-F1 65425)
(define XK:KP-F2 65426)
(define XK:KP-F3 65427)
(define XK:KP-F4 65428)
(define XK:KP-Home 65429)
(define XK:KP-Left 65430)
(define XK:KP-Up 65431)
(define XK:KP-Right 65432)
(define XK:KP-Down 65433)
(define XK:KP-Prior 65434)
(define XK:KP-Page-Up 65434)
(define XK:KP-Next 65435)
(define XK:KP-Page-Down 65435)
(define XK:KP-End 65436)
(define XK:KP-Begin 65437)
(define XK:KP-Insert 65438)
(define XK:KP-Delete 65439)
(define XK:KP-Equal 65469)
(define XK:KP-Multiply 65450)
(define XK:KP-Add 65451)
(define XK:KP-Separator 65452)
(define XK:KP-Subtract 65453)
(define XK:KP-Decimal 65454)
(define XK:KP-Divide 65455)
(define XK:KP-0 65456)
(define XK:KP-1 65457)
(define XK:KP-2 65458)
(define XK:KP-3 65459)
(define XK:KP-4 65460)
(define XK:KP-5 65461)
(define XK:KP-6 65462)
(define XK:KP-7 65463)
(define XK:KP-8 65464)
(define XK:KP-9 65465)
(define XK:F1 65470)
(define XK:F2 65471)
(define XK:F3 65472)
(define XK:F4 65473)
(define XK:F5 65474)
(define XK:F6 65475)
(define XK:F7 65476)
(define XK:F8 65477)
(define XK:F9 65478)
(define XK:F10 65479)
(define XK:F11 65480)
(define XK:L1 65480)
(define XK:F12 65481)
(define XK:L2 65481)
(define XK:F13 65482)
(define XK:L3 65482)
(define XK:F14 65483)
(define XK:L4 65483)
(define XK:F15 65484)
(define XK:L5 65484)
(define XK:F16 65485)
(define XK:L6 65485)
(define XK:F17 65486)
(define XK:L7 65486)
(define XK:F18 65487)
(define XK:L8 65487)
(define XK:F19 65488)
(define XK:L9 65488)
(define XK:F20 65489)
(define XK:L10 65489)
(define XK:F21 65490)
(define XK:R1 65490)
(define XK:F22 65491)
(define XK:R2 65491)
(define XK:F23 65492)
(define XK:R3 65492)
(define XK:F24 65493)
(define XK:R4 65493)
(define XK:F25 65494)
(define XK:R5 65494)
(define XK:F26 65495)
(define XK:R6 65495)
(define XK:F27 65496)
(define XK:R7 65496)
(define XK:F28 65497)
(define XK:R8 65497)
(define XK:F29 65498)
(define XK:R9 65498)
(define XK:F30 65499)
(define XK:R10 65499)
(define XK:F31 65500)
(define XK:R11 65500)
(define XK:F32 65501)
(define XK:R12 65501)
(define XK:F33 65502)
(define XK:R13 65502)
(define XK:F34 65503)
(define XK:R14 65503)
(define XK:F35 65504)
(define XK:R15 65504)
(define XK:Shift-L 65505)
(define XK:Shift-R 65506)
(define XK:Control-L 65507)
(define XK:Control-R 65508)
(define XK:Caps-Lock 65509)
(define XK:Shift-Lock 65510)
(define XK:Meta-L 65511)
(define XK:Meta-R 65512)
(define XK:Alt-L 65513)
(define XK:Alt-R 65514)
(define XK:Super-L 65515)
(define XK:Super-R 65516)
(define XK:Hyper-L 65517)
(define XK:Hyper-R 65518)
(define XK:ISO-Lock 65025)
(define XK:ISO-Level2-Latch 65026)
(define XK:ISO-Level3-Shift 65027)
(define XK:ISO-Level3-Latch 65028)
(define XK:ISO-Level3-Lock 65029)
(define XK:ISO-Level5-Shift 65041)
(define XK:ISO-Level5-Latch 65042)
(define XK:ISO-Level5-Lock 65043)
(define XK:ISO-Group-Shift 65406)
(define XK:ISO-Group-Latch 65030)
(define XK:ISO-Group-Lock 65031)
(define XK:ISO-Next-Group 65032)
(define XK:ISO-Next-Group-Lock 65033)
(define XK:ISO-Prev-Group 65034)
(define XK:ISO-Prev-Group-Lock 65035)
(define XK:ISO-First-Group 65036)
(define XK:ISO-First-Group-Lock 65037)
(define XK:ISO-Last-Group 65038)
(define XK:ISO-Last-Group-Lock 65039)
(define XK:ISO-Left-Tab 65056)
(define XK:ISO-Move-Line-Up 65057)
(define XK:ISO-Move-Line-Down 65058)
(define XK:ISO-Partial-Line-Up 65059)
(define XK:ISO-Partial-Line-Down 65060)
(define XK:ISO-Partial-Space-Left 65061)
(define XK:ISO-Partial-Space-Right 65062)
(define XK:ISO-Set-Margin-Left 65063)
(define XK:ISO-Set-Margin-Right 65064)
(define XK:ISO-Release-Margin-Left 65065)
(define XK:ISO-Release-Margin-Right 65066)
(define XK:ISO-Release-Both-Margins 65067)
(define XK:ISO-Fast-Cursor-Left 65068)
(define XK:ISO-Fast-Cursor-Right 65069)
(define XK:ISO-Fast-Cursor-Up 65070)
(define XK:ISO-Fast-Cursor-Down 65071)
(define XK:ISO-Continuous-Underline 65072)
(define XK:ISO-Discontinuous-Underline 65073)
(define XK:ISO-Emphasize 65074)
(define XK:ISO-Center-Object 65075)
(define XK:ISO-Enter 65076)
(define XK:dead-grave 65104)
(define XK:dead-acute 65105)
(define XK:dead-circumflex 65106)
(define XK:dead-tilde 65107)
(define XK:dead-perispomeni 65107)
(define XK:dead-macron 65108)
(define XK:dead-breve 65109)
(define XK:dead-abovedot 65110)
(define XK:dead-diaeresis 65111)
(define XK:dead-abovering 65112)
(define XK:dead-doubleacute 65113)
(define XK:dead-caron 65114)
(define XK:dead-cedilla 65115)
(define XK:dead-ogonek 65116)
(define XK:dead-iota 65117)
(define XK:dead-voiced-sound 65118)
(define XK:dead-semivoiced-sound 65119)
(define XK:dead-belowdot 65120)
(define XK:dead-hook 65121)
(define XK:dead-horn 65122)
(define XK:dead-stroke 65123)
(define XK:dead-abovecomma 65124)
(define XK:dead-psili 65124)
(define XK:dead-abovereversedcomma 65125)
(define XK:dead-dasia 65125)
(define XK:dead-doublegrave 65126)
(define XK:dead-belowring 65127)
(define XK:dead-belowmacron 65128)
(define XK:dead-belowcircumflex 65129)
(define XK:dead-belowtilde 65130)
(define XK:dead-belowbreve 65131)
(define XK:dead-belowdiaeresis 65132)
(define XK:dead-invertedbreve 65133)
(define XK:dead-belowcomma 65134)
(define XK:dead-currency 65135)
(define XK:dead-lowline 65168)
(define XK:dead-aboveverticalline 65169)
(define XK:dead-belowverticalline 65170)
(define XK:dead-longsolidusoverlay 65171)
(define XK:dead-a 65152)
(define XK:dead-A 65153)
(define XK:dead-e 65154)
(define XK:dead-E 65155)
(define XK:dead-i 65156)
(define XK:dead-I 65157)
(define XK:dead-o 65158)
(define XK:dead-O 65159)
(define XK:dead-u 65160)
(define XK:dead-U 65161)
(define XK:dead-small-schwa 65162)
(define XK:dead-capital-schwa 65163)
(define XK:dead-greek 65164)
(define XK:First-Virtual-Screen 65232)
(define XK:Prev-Virtual-Screen 65233)
(define XK:Next-Virtual-Screen 65234)
(define XK:Last-Virtual-Screen 65236)
(define XK:Terminate-Server 65237)
(define XK:AccessX-Enable 65136)
(define XK:AccessX-Feedback-Enable 65137)
(define XK:RepeatKeys-Enable 65138)
(define XK:SlowKeys-Enable 65139)
(define XK:BounceKeys-Enable 65140)
(define XK:StickyKeys-Enable 65141)
(define XK:MouseKeys-Enable 65142)
(define XK:MouseKeys-Accel-Enable 65143)
(define XK:Overlay1-Enable 65144)
(define XK:Overlay2-Enable 65145)
(define XK:AudibleBell-Enable 65146)
(define XK:Pointer-Left 65248)
(define XK:Pointer-Right 65249)
(define XK:Pointer-Up 65250)
(define XK:Pointer-Down 65251)
(define XK:Pointer-UpLeft 65252)
(define XK:Pointer-UpRight 65253)
(define XK:Pointer-DownLeft 65254)
(define XK:Pointer-DownRight 65255)
(define XK:Pointer-Button-Dflt 65256)
(define XK:Pointer-Button1 65257)
(define XK:Pointer-Button2 65258)
(define XK:Pointer-Button3 65259)
(define XK:Pointer-Button4 65260)
(define XK:Pointer-Button5 65261)
(define XK:Pointer-DblClick-Dflt 65262)
(define XK:Pointer-DblClick1 65263)
(define XK:Pointer-DblClick2 65264)
(define XK:Pointer-DblClick3 65265)
(define XK:Pointer-DblClick4 65266)
(define XK:Pointer-DblClick5 65267)
(define XK:Pointer-Drag-Dflt 65268)
(define XK:Pointer-Drag1 65269)
(define XK:Pointer-Drag2 65270)
(define XK:Pointer-Drag3 65271)
(define XK:Pointer-Drag4 65272)
(define XK:Pointer-Drag5 65277)
(define XK:Pointer-EnableKeys 65273)
(define XK:Pointer-Accelerate 65274)
(define XK:Pointer-DfltBtnNext 65275)
(define XK:Pointer-DfltBtnPrev 65276)
(define XK:ch 65184)
(define XK:Ch 65185)
(define XK:CH 65186)
(define XK:c-h 65187)
(define XK:C-h 65188)
(define XK:C-H 65189)
(define XK:space 32)
(define XK:exclam 33)
(define XK:quotedbl 34)
(define XK:numbersign 35)
(define XK:dollar 36)
(define XK:percent 37)
(define XK:ampersand 38)
(define XK:apostrophe 39)
(define XK:quoteright 39)
(define XK:parenleft 40)
(define XK:parenright 41)
(define XK:asterisk 42)
(define XK:plus 43)
(define XK:comma 44)
(define XK:minus 45)
(define XK:period 46)
(define XK:slash 47)
(define XK:0 48)
(define XK:1 49)
(define XK:2 50)
(define XK:3 51)
(define XK:4 52)
(define XK:5 53)
(define XK:6 54)
(define XK:7 55)
(define XK:8 56)
(define XK:9 57)
(define XK:colon 58)
(define XK:semicolon 59)
(define XK:less 60)
(define XK:equal 61)
(define XK:greater 62)
(define XK:question 63)
(define XK:at 64)
(define XK:A 65)
(define XK:B 66)
(define XK:C 67)
(define XK:D 68)
(define XK:E 69)
(define XK:F 70)
(define XK:G 71)
(define XK:H 72)
(define XK:I 73)
(define XK:J 74)
(define XK:K 75)
(define XK:L 76)
(define XK:M 77)
(define XK:N 78)
(define XK:O 79)
(define XK:P 80)
(define XK:Q 81)
(define XK:R 82)
(define XK:S 83)
(define XK:T 84)
(define XK:U 85)
(define XK:V 86)
(define XK:W 87)
(define XK:X 88)
(define XK:Y 89)
(define XK:Z 90)
(define XK:bracketleft 91)
(define XK:backslash 92)
(define XK:bracketright 93)
(define XK:asciicircum 94)
(define XK:underscore 95)
(define XK:grave 96)
(define XK:quoteleft 96)
(define XK:a 97)
(define XK:b 98)
(define XK:c 99)
(define XK:d 100)
(define XK:e 101)
(define XK:f 102)
(define XK:g 103)
(define XK:h 104)
(define XK:i 105)
(define XK:j 106)
(define XK:k 107)
(define XK:l 108)
(define XK:m 109)
(define XK:n 110)
(define XK:o 111)
(define XK:p 112)
(define XK:q 113)
(define XK:r 114)
(define XK:s 115)
(define XK:t 116)
(define XK:u 117)
(define XK:v 118)
(define XK:w 119)
(define XK:x 120)
(define XK:y 121)
(define XK:z 122)
(define XK:braceleft 123)
(define XK:bar 124)
(define XK:braceright 125)
(define XK:asciitilde 126)
(define XK:nobreakspace 160)
(define XK:exclamdown 161)
(define XK:cent 162)
(define XK:sterling 163)
(define XK:currency 164)
(define XK:yen 165)
(define XK:brokenbar 166)
(define XK:section 167)
(define XK:diaeresis 168)
(define XK:copyright 169)
(define XK:ordfeminine 170)
(define XK:guillemotleft 171)
(define XK:notsign 172)
(define XK:hyphen 173)
(define XK:registered 174)
(define XK:macron 175)
(define XK:degree 176)
(define XK:plusminus 177)
(define XK:twosuperior 178)
(define XK:threesuperior 179)
(define XK:acute 180)
(define XK:mu 181)
(define XK:paragraph 182)
(define XK:periodcentered 183)
(define XK:cedilla 184)
(define XK:onesuperior 185)
(define XK:masculine 186)
(define XK:guillemotright 187)
(define XK:onequarter 188)
(define XK:onehalf 189)
(define XK:threequarters 190)
(define XK:questiondown 191)
(define XK:Agrave 192)
(define XK:Aacute 193)
(define XK:Acircumflex 194)
(define XK:Atilde 195)
(define XK:Adiaeresis 196)
(define XK:Aring 197)
(define XK:AE 198)
(define XK:Ccedilla 199)
(define XK:Egrave 200)
(define XK:Eacute 201)
(define XK:Ecircumflex 202)
(define XK:Ediaeresis 203)
(define XK:Igrave 204)
(define XK:Iacute 205)
(define XK:Icircumflex 206)
(define XK:Idiaeresis 207)
(define XK:ETH 208)
(define XK:Eth 208)
(define XK:Ntilde 209)
(define XK:Ograve 210)
(define XK:Oacute 211)
(define XK:Ocircumflex 212)
(define XK:Otilde 213)
(define XK:Odiaeresis 214)
(define XK:multiply 215)
(define XK:Oslash 216)
(define XK:Ooblique 216)
(define XK:Ugrave 217)
(define XK:Uacute 218)
(define XK:Ucircumflex 219)
(define XK:Udiaeresis 220)
(define XK:Yacute 221)
(define XK:THORN 222)
(define XK:Thorn 222)
(define XK:ssharp 223)
(define XK:agrave 224)
(define XK:aacute 225)
(define XK:acircumflex 226)
(define XK:atilde 227)
(define XK:adiaeresis 228)
(define XK:aring 229)
(define XK:ae 230)
(define XK:ccedilla 231)
(define XK:egrave 232)
(define XK:eacute 233)
(define XK:ecircumflex 234)
(define XK:ediaeresis 235)
(define XK:igrave 236)
(define XK:iacute 237)
(define XK:icircumflex 238)
(define XK:idiaeresis 239)
(define XK:eth 240)
(define XK:ntilde 241)
(define XK:ograve 242)
(define XK:oacute 243)
(define XK:ocircumflex 244)
(define XK:otilde 245)
(define XK:odiaeresis 246)
(define XK:division 247)
(define XK:oslash 248)
(define XK:ooblique 248)
(define XK:ugrave 249)
(define XK:uacute 250)
(define XK:ucircumflex 251)
(define XK:udiaeresis 252)
(define XK:yacute 253)
(define XK:thorn 254)
(define XK:ydiaeresis 255)
(define XK:Aogonek 417)
(define XK:breve 418)
(define XK:Lstroke 419)
(define XK:Lcaron 421)
(define XK:Sacute 422)
(define XK:Scaron 425)
(define XK:Scedilla 426)
(define XK:Tcaron 427)
(define XK:Zacute 428)
(define XK:Zcaron 430)
(define XK:Zabovedot 431)
(define XK:aogonek 433)
(define XK:ogonek 434)
(define XK:lstroke 435)
(define XK:lcaron 437)
(define XK:sacute 438)
(define XK:caron 439)
(define XK:scaron 441)
(define XK:scedilla 442)
(define XK:tcaron 443)
(define XK:zacute 444)
(define XK:doubleacute 445)
(define XK:zcaron 446)
(define XK:zabovedot 447)
(define XK:Racute 448)
(define XK:Abreve 451)
(define XK:Lacute 453)
(define XK:Cacute 454)
(define XK:Ccaron 456)
(define XK:Eogonek 458)
(define XK:Ecaron 460)
(define XK:Dcaron 463)
(define XK:Dstroke 464)
(define XK:Nacute 465)
(define XK:Ncaron 466)
(define XK:Odoubleacute 469)
(define XK:Rcaron 472)
(define XK:Uring 473)
(define XK:Udoubleacute 475)
(define XK:Tcedilla 478)
(define XK:racute 480)
(define XK:abreve 483)
(define XK:lacute 485)
(define XK:cacute 486)
(define XK:ccaron 488)
(define XK:eogonek 490)
(define XK:ecaron 492)
(define XK:dcaron 495)
(define XK:dstroke 496)
(define XK:nacute 497)
(define XK:ncaron 498)
(define XK:odoubleacute 501)
(define XK:rcaron 504)
(define XK:uring 505)
(define XK:udoubleacute 507)
(define XK:tcedilla 510)
(define XK:abovedot 511)
(define XK:Hstroke 673)
(define XK:Hcircumflex 678)
(define XK:Iabovedot 681)
(define XK:Gbreve 683)
(define XK:Jcircumflex 684)
(define XK:hstroke 689)
(define XK:hcircumflex 694)
(define XK:idotless 697)
(define XK:gbreve 699)
(define XK:jcircumflex 700)
(define XK:Cabovedot 709)
(define XK:Ccircumflex 710)
(define XK:Gabovedot 725)
(define XK:Gcircumflex 728)
(define XK:Ubreve 733)
(define XK:Scircumflex 734)
(define XK:cabovedot 741)
(define XK:ccircumflex 742)
(define XK:gabovedot 757)
(define XK:gcircumflex 760)
(define XK:ubreve 765)
(define XK:scircumflex 766)
(define XK:kra 930)
(define XK:kappa 930)
(define XK:Rcedilla 931)
(define XK:Itilde 933)
(define XK:Lcedilla 934)
(define XK:Emacron 938)
(define XK:Gcedilla 939)
(define XK:Tslash 940)
(define XK:rcedilla 947)
(define XK:itilde 949)
(define XK:lcedilla 950)
(define XK:emacron 954)
(define XK:gcedilla 955)
(define XK:tslash 956)
(define XK:ENG 957)
(define XK:eng 959)
(define XK:Amacron 960)
(define XK:Iogonek 967)
(define XK:Eabovedot 972)
(define XK:Imacron 975)
(define XK:Ncedilla 977)
(define XK:Omacron 978)
(define XK:Kcedilla 979)
(define XK:Uogonek 985)
(define XK:Utilde 989)
(define XK:Umacron 990)
(define XK:amacron 992)
(define XK:iogonek 999)
(define XK:eabovedot 1004)
(define XK:imacron 1007)
(define XK:ncedilla 1009)
(define XK:omacron 1010)
(define XK:kcedilla 1011)
(define XK:uogonek 1017)
(define XK:utilde 1021)
(define XK:umacron 1022)
(define XK:Wcircumflex 16777588)
(define XK:wcircumflex 16777589)
(define XK:Ycircumflex 16777590)
(define XK:ycircumflex 16777591)
(define XK:Babovedot 16784898)
(define XK:babovedot 16784899)
(define XK:Dabovedot 16784906)
(define XK:dabovedot 16784907)
(define XK:Fabovedot 16784926)
(define XK:fabovedot 16784927)
(define XK:Mabovedot 16784960)
(define XK:mabovedot 16784961)
(define XK:Pabovedot 16784982)
(define XK:pabovedot 16784983)
(define XK:Sabovedot 16784992)
(define XK:sabovedot 16784993)
(define XK:Tabovedot 16785002)
(define XK:tabovedot 16785003)
(define XK:Wgrave 16785024)
(define XK:wgrave 16785025)
(define XK:Wacute 16785026)
(define XK:wacute 16785027)
(define XK:Wdiaeresis 16785028)
(define XK:wdiaeresis 16785029)
(define XK:Ygrave 16785138)
(define XK:ygrave 16785139)
(define XK:OE 5052)
(define XK:oe 5053)
(define XK:Ydiaeresis 5054)
(define XK:overline 1150)
(define XK:kana-fullstop 1185)
(define XK:kana-openingbracket 1186)
(define XK:kana-closingbracket 1187)
(define XK:kana-comma 1188)
(define XK:kana-conjunctive 1189)
(define XK:kana-middledot 1189)
(define XK:kana-WO 1190)
(define XK:kana-a 1191)
(define XK:kana-i 1192)
(define XK:kana-u 1193)
(define XK:kana-e 1194)
(define XK:kana-o 1195)
(define XK:kana-ya 1196)
(define XK:kana-yu 1197)
(define XK:kana-yo 1198)
(define XK:kana-tsu 1199)
(define XK:kana-tu 1199)
(define XK:prolongedsound 1200)
(define XK:kana-A 1201)
(define XK:kana-I 1202)
(define XK:kana-U 1203)
(define XK:kana-E 1204)
(define XK:kana-O 1205)
(define XK:kana-KA 1206)
(define XK:kana-KI 1207)
(define XK:kana-KU 1208)
(define XK:kana-KE 1209)
(define XK:kana-KO 1210)
(define XK:kana-SA 1211)
(define XK:kana-SHI 1212)
(define XK:kana-SU 1213)
(define XK:kana-SE 1214)
(define XK:kana-SO 1215)
(define XK:kana-TA 1216)
(define XK:kana-CHI 1217)
(define XK:kana-TI 1217)
(define XK:kana-TSU 1218)
(define XK:kana-TU 1218)
(define XK:kana-TE 1219)
(define XK:kana-TO 1220)
(define XK:kana-NA 1221)
(define XK:kana-NI 1222)
(define XK:kana-NU 1223)
(define XK:kana-NE 1224)
(define XK:kana-NO 1225)
(define XK:kana-HA 1226)
(define XK:kana-HI 1227)
(define XK:kana-FU 1228)
(define XK:kana-HU 1228)
(define XK:kana-HE 1229)
(define XK:kana-HO 1230)
(define XK:kana-MA 1231)
(define XK:kana-MI 1232)
(define XK:kana-MU 1233)
(define XK:kana-ME 1234)
(define XK:kana-MO 1235)
(define XK:kana-YA 1236)
(define XK:kana-YU 1237)
(define XK:kana-YO 1238)
(define XK:kana-RA 1239)
(define XK:kana-RI 1240)
(define XK:kana-RU 1241)
(define XK:kana-RE 1242)
(define XK:kana-RO 1243)
(define XK:kana-WA 1244)
(define XK:kana-N 1245)
(define XK:voicedsound 1246)
(define XK:semivoicedsound 1247)
(define XK:kana-switch 65406)
(define XK:Farsi-0 16778992)
(define XK:Farsi-1 16778993)
(define XK:Farsi-2 16778994)
(define XK:Farsi-3 16778995)
(define XK:Farsi-4 16778996)
(define XK:Farsi-5 16778997)
(define XK:Farsi-6 16778998)
(define XK:Farsi-7 16778999)
(define XK:Farsi-8 16779000)
(define XK:Farsi-9 16779001)
(define XK:Arabic-percent 16778858)
(define XK:Arabic-superscript-alef 16778864)
(define XK:Arabic-tteh 16778873)
(define XK:Arabic-peh 16778878)
(define XK:Arabic-tcheh 16778886)
(define XK:Arabic-ddal 16778888)
(define XK:Arabic-rreh 16778897)
(define XK:Arabic-comma 1452)
(define XK:Arabic-fullstop 16778964)
(define XK:Arabic-0 16778848)
(define XK:Arabic-1 16778849)
(define XK:Arabic-2 16778850)
(define XK:Arabic-3 16778851)
(define XK:Arabic-4 16778852)
(define XK:Arabic-5 16778853)
(define XK:Arabic-6 16778854)
(define XK:Arabic-7 16778855)
(define XK:Arabic-8 16778856)
(define XK:Arabic-9 16778857)
(define XK:Arabic-semicolon 1467)
(define XK:Arabic-question-mark 1471)
(define XK:Arabic-hamza 1473)
(define XK:Arabic-maddaonalef 1474)
(define XK:Arabic-hamzaonalef 1475)
(define XK:Arabic-hamzaonwaw 1476)
(define XK:Arabic-hamzaunderalef 1477)
(define XK:Arabic-hamzaonyeh 1478)
(define XK:Arabic-alef 1479)
(define XK:Arabic-beh 1480)
(define XK:Arabic-tehmarbuta 1481)
(define XK:Arabic-teh 1482)
(define XK:Arabic-theh 1483)
(define XK:Arabic-jeem 1484)
(define XK:Arabic-hah 1485)
(define XK:Arabic-khah 1486)
(define XK:Arabic-dal 1487)
(define XK:Arabic-thal 1488)
(define XK:Arabic-ra 1489)
(define XK:Arabic-zain 1490)
(define XK:Arabic-seen 1491)
(define XK:Arabic-sheen 1492)
(define XK:Arabic-sad 1493)
(define XK:Arabic-dad 1494)
(define XK:Arabic-tah 1495)
(define XK:Arabic-zah 1496)
(define XK:Arabic-ain 1497)
(define XK:Arabic-ghain 1498)
(define XK:Arabic-tatweel 1504)
(define XK:Arabic-feh 1505)
(define XK:Arabic-qaf 1506)
(define XK:Arabic-kaf 1507)
(define XK:Arabic-lam 1508)
(define XK:Arabic-meem 1509)
(define XK:Arabic-noon 1510)
(define XK:Arabic-ha 1511)
(define XK:Arabic-heh 1511)
(define XK:Arabic-waw 1512)
(define XK:Arabic-alefmaksura 1513)
(define XK:Arabic-yeh 1514)
(define XK:Arabic-fathatan 1515)
(define XK:Arabic-dammatan 1516)
(define XK:Arabic-kasratan 1517)
(define XK:Arabic-fatha 1518)
(define XK:Arabic-damma 1519)
(define XK:Arabic-kasra 1520)
(define XK:Arabic-shadda 1521)
(define XK:Arabic-sukun 1522)
(define XK:Arabic-madda-above 16778835)
(define XK:Arabic-hamza-above 16778836)
(define XK:Arabic-hamza-below 16778837)
(define XK:Arabic-jeh 16778904)
(define XK:Arabic-veh 16778916)
(define XK:Arabic-keheh 16778921)
(define XK:Arabic-gaf 16778927)
(define XK:Arabic-noon-ghunna 16778938)
(define XK:Arabic-heh-doachashmee 16778942)
(define XK:Farsi-yeh 16778956)
(define XK:Arabic-farsi-yeh 16778956)
(define XK:Arabic-yeh-baree 16778962)
(define XK:Arabic-heh-goal 16778945)
(define XK:Arabic-switch 65406)
(define XK:Cyrillic-GHE-bar 16778386)
(define XK:Cyrillic-ghe-bar 16778387)
(define XK:Cyrillic-ZHE-descender 16778390)
(define XK:Cyrillic-zhe-descender 16778391)
(define XK:Cyrillic-KA-descender 16778394)
(define XK:Cyrillic-ka-descender 16778395)
(define XK:Cyrillic-KA-vertstroke 16778396)
(define XK:Cyrillic-ka-vertstroke 16778397)
(define XK:Cyrillic-EN-descender 16778402)
(define XK:Cyrillic-en-descender 16778403)
(define XK:Cyrillic-U-straight 16778414)
(define XK:Cyrillic-u-straight 16778415)
(define XK:Cyrillic-U-straight-bar 16778416)
(define XK:Cyrillic-u-straight-bar 16778417)
(define XK:Cyrillic-HA-descender 16778418)
(define XK:Cyrillic-ha-descender 16778419)
(define XK:Cyrillic-CHE-descender 16778422)
(define XK:Cyrillic-che-descender 16778423)
(define XK:Cyrillic-CHE-vertstroke 16778424)
(define XK:Cyrillic-che-vertstroke 16778425)
(define XK:Cyrillic-SHHA 16778426)
(define XK:Cyrillic-shha 16778427)
(define XK:Cyrillic-SCHWA 16778456)
(define XK:Cyrillic-schwa 16778457)
(define XK:Cyrillic-I-macron 16778466)
(define XK:Cyrillic-i-macron 16778467)
(define XK:Cyrillic-O-bar 16778472)
(define XK:Cyrillic-o-bar 16778473)
(define XK:Cyrillic-U-macron 16778478)
(define XK:Cyrillic-u-macron 16778479)
(define XK:Serbian-dje 1697)
(define XK:Macedonia-gje 1698)
(define XK:Cyrillic-io 1699)
(define XK:Ukrainian-ie 1700)
(define XK:Ukranian-je 1700)
(define XK:Macedonia-dse 1701)
(define XK:Ukrainian-i 1702)
(define XK:Ukranian-i 1702)
(define XK:Ukrainian-yi 1703)
(define XK:Ukranian-yi 1703)
(define XK:Cyrillic-je 1704)
(define XK:Serbian-je 1704)
(define XK:Cyrillic-lje 1705)
(define XK:Serbian-lje 1705)
(define XK:Cyrillic-nje 1706)
(define XK:Serbian-nje 1706)
(define XK:Serbian-tshe 1707)
(define XK:Macedonia-kje 1708)
(define XK:Ukrainian-ghe-with-upturn 1709)
(define XK:Byelorussian-shortu 1710)
(define XK:Cyrillic-dzhe 1711)
(define XK:Serbian-dze 1711)
(define XK:numerosign 1712)
(define XK:Serbian-DJE 1713)
(define XK:Macedonia-GJE 1714)
(define XK:Cyrillic-IO 1715)
(define XK:Ukrainian-IE 1716)
(define XK:Ukranian-JE 1716)
(define XK:Macedonia-DSE 1717)
(define XK:Ukrainian-I 1718)
(define XK:Ukranian-I 1718)
(define XK:Ukrainian-YI 1719)
(define XK:Ukranian-YI 1719)
(define XK:Cyrillic-JE 1720)
(define XK:Serbian-JE 1720)
(define XK:Cyrillic-LJE 1721)
(define XK:Serbian-LJE 1721)
(define XK:Cyrillic-NJE 1722)
(define XK:Serbian-NJE 1722)
(define XK:Serbian-TSHE 1723)
(define XK:Macedonia-KJE 1724)
(define XK:Ukrainian-GHE-WITH-UPTURN 1725)
(define XK:Byelorussian-SHORTU 1726)
(define XK:Cyrillic-DZHE 1727)
(define XK:Serbian-DZE 1727)
(define XK:Cyrillic-yu 1728)
(define XK:Cyrillic-a 1729)
(define XK:Cyrillic-be 1730)
(define XK:Cyrillic-tse 1731)
(define XK:Cyrillic-de 1732)
(define XK:Cyrillic-ie 1733)
(define XK:Cyrillic-ef 1734)
(define XK:Cyrillic-ghe 1735)
(define XK:Cyrillic-ha 1736)
(define XK:Cyrillic-i 1737)
(define XK:Cyrillic-shorti 1738)
(define XK:Cyrillic-ka 1739)
(define XK:Cyrillic-el 1740)
(define XK:Cyrillic-em 1741)
(define XK:Cyrillic-en 1742)
(define XK:Cyrillic-o 1743)
(define XK:Cyrillic-pe 1744)
(define XK:Cyrillic-ya 1745)
(define XK:Cyrillic-er 1746)
(define XK:Cyrillic-es 1747)
(define XK:Cyrillic-te 1748)
(define XK:Cyrillic-u 1749)
(define XK:Cyrillic-zhe 1750)
(define XK:Cyrillic-ve 1751)
(define XK:Cyrillic-softsign 1752)
(define XK:Cyrillic-yeru 1753)
(define XK:Cyrillic-ze 1754)
(define XK:Cyrillic-sha 1755)
(define XK:Cyrillic-e 1756)
(define XK:Cyrillic-shcha 1757)
(define XK:Cyrillic-che 1758)
(define XK:Cyrillic-hardsign 1759)
(define XK:Cyrillic-YU 1760)
(define XK:Cyrillic-A 1761)
(define XK:Cyrillic-BE 1762)
(define XK:Cyrillic-TSE 1763)
(define XK:Cyrillic-DE 1764)
(define XK:Cyrillic-IE 1765)
(define XK:Cyrillic-EF 1766)
(define XK:Cyrillic-GHE 1767)
(define XK:Cyrillic-HA 1768)
(define XK:Cyrillic-I 1769)
(define XK:Cyrillic-SHORTI 1770)
(define XK:Cyrillic-KA 1771)
(define XK:Cyrillic-EL 1772)
(define XK:Cyrillic-EM 1773)
(define XK:Cyrillic-EN 1774)
(define XK:Cyrillic-O 1775)
(define XK:Cyrillic-PE 1776)
(define XK:Cyrillic-YA 1777)
(define XK:Cyrillic-ER 1778)
(define XK:Cyrillic-ES 1779)
(define XK:Cyrillic-TE 1780)
(define XK:Cyrillic-U 1781)
(define XK:Cyrillic-ZHE 1782)
(define XK:Cyrillic-VE 1783)
(define XK:Cyrillic-SOFTSIGN 1784)
(define XK:Cyrillic-YERU 1785)
(define XK:Cyrillic-ZE 1786)
(define XK:Cyrillic-SHA 1787)
(define XK:Cyrillic-E 1788)
(define XK:Cyrillic-SHCHA 1789)
(define XK:Cyrillic-CHE 1790)
(define XK:Cyrillic-HARDSIGN 1791)
(define XK:Greek-ALPHAaccent 1953)
(define XK:Greek-EPSILONaccent 1954)
(define XK:Greek-ETAaccent 1955)
(define XK:Greek-IOTAaccent 1956)
(define XK:Greek-IOTAdieresis 1957)
(define XK:Greek-IOTAdiaeresis 1957)
(define XK:Greek-OMICRONaccent 1959)
(define XK:Greek-UPSILONaccent 1960)
(define XK:Greek-UPSILONdieresis 1961)
(define XK:Greek-OMEGAaccent 1963)
(define XK:Greek-accentdieresis 1966)
(define XK:Greek-horizbar 1967)
(define XK:Greek-alphaaccent 1969)
(define XK:Greek-epsilonaccent 1970)
(define XK:Greek-etaaccent 1971)
(define XK:Greek-iotaaccent 1972)
(define XK:Greek-iotadieresis 1973)
(define XK:Greek-iotaaccentdieresis 1974)
(define XK:Greek-omicronaccent 1975)
(define XK:Greek-upsilonaccent 1976)
(define XK:Greek-upsilondieresis 1977)
(define XK:Greek-upsilonaccentdieresis 1978)
(define XK:Greek-omegaaccent 1979)
(define XK:Greek-ALPHA 1985)
(define XK:Greek-BETA 1986)
(define XK:Greek-GAMMA 1987)
(define XK:Greek-DELTA 1988)
(define XK:Greek-EPSILON 1989)
(define XK:Greek-ZETA 1990)
(define XK:Greek-ETA 1991)
(define XK:Greek-THETA 1992)
(define XK:Greek-IOTA 1993)
(define XK:Greek-KAPPA 1994)
(define XK:Greek-LAMDA 1995)
(define XK:Greek-LAMBDA 1995)
(define XK:Greek-MU 1996)
(define XK:Greek-NU 1997)
(define XK:Greek-XI 1998)
(define XK:Greek-OMICRON 1999)
(define XK:Greek-PI 2000)
(define XK:Greek-RHO 2001)
(define XK:Greek-SIGMA 2002)
(define XK:Greek-TAU 2004)
(define XK:Greek-UPSILON 2005)
(define XK:Greek-PHI 2006)
(define XK:Greek-CHI 2007)
(define XK:Greek-PSI 2008)
(define XK:Greek-OMEGA 2009)
(define XK:Greek-alpha 2017)
(define XK:Greek-beta 2018)
(define XK:Greek-gamma 2019)
(define XK:Greek-delta 2020)
(define XK:Greek-epsilon 2021)
(define XK:Greek-zeta 2022)
(define XK:Greek-eta 2023)
(define XK:Greek-theta 2024)
(define XK:Greek-iota 2025)
(define XK:Greek-kappa 2026)
(define XK:Greek-lamda 2027)
(define XK:Greek-lambda 2027)
(define XK:Greek-mu 2028)
(define XK:Greek-nu 2029)
(define XK:Greek-xi 2030)
(define XK:Greek-omicron 2031)
(define XK:Greek-pi 2032)
(define XK:Greek-rho 2033)
(define XK:Greek-sigma 2034)
(define XK:Greek-finalsmallsigma 2035)
(define XK:Greek-tau 2036)
(define XK:Greek-upsilon 2037)
(define XK:Greek-phi 2038)
(define XK:Greek-chi 2039)
(define XK:Greek-psi 2040)
(define XK:Greek-omega 2041)
(define XK:Greek-switch 65406)
(define XK:hebrew-doublelowline 3295)
(define XK:hebrew-aleph 3296)
(define XK:hebrew-bet 3297)
(define XK:hebrew-beth 3297)
(define XK:hebrew-gimel 3298)
(define XK:hebrew-gimmel 3298)
(define XK:hebrew-dalet 3299)
(define XK:hebrew-daleth 3299)
(define XK:hebrew-he 3300)
(define XK:hebrew-waw 3301)
(define XK:hebrew-zain 3302)
(define XK:hebrew-zayin 3302)
(define XK:hebrew-chet 3303)
(define XK:hebrew-het 3303)
(define XK:hebrew-tet 3304)
(define XK:hebrew-teth 3304)
(define XK:hebrew-yod 3305)
(define XK:hebrew-finalkaph 3306)
(define XK:hebrew-kaph 3307)
(define XK:hebrew-lamed 3308)
(define XK:hebrew-finalmem 3309)
(define XK:hebrew-mem 3310)
(define XK:hebrew-finalnun 3311)
(define XK:hebrew-nun 3312)
(define XK:hebrew-samech 3313)
(define XK:hebrew-samekh 3313)
(define XK:hebrew-ayin 3314)
(define XK:hebrew-finalpe 3315)
(define XK:hebrew-pe 3316)
(define XK:hebrew-finalzade 3317)
(define XK:hebrew-finalzadi 3317)
(define XK:hebrew-zade 3318)
(define XK:hebrew-zadi 3318)
(define XK:hebrew-qoph 3319)
(define XK:hebrew-kuf 3319)
(define XK:hebrew-resh 3320)
(define XK:hebrew-shin 3321)
(define XK:hebrew-taw 3322)
(define XK:hebrew-taf 3322)
(define XK:Hebrew-switch 65406)
(define XK:Thai-kokai 3489)
(define XK:Thai-khokhai 3490)
(define XK:Thai-khokhuat 3491)
(define XK:Thai-khokhwai 3492)
(define XK:Thai-khokhon 3493)
(define XK:Thai-khorakhang 3494)
(define XK:Thai-ngongu 3495)
(define XK:Thai-chochan 3496)
(define XK:Thai-choching 3497)
(define XK:Thai-chochang 3498)
(define XK:Thai-soso 3499)
(define XK:Thai-chochoe 3500)
(define XK:Thai-yoying 3501)
(define XK:Thai-dochada 3502)
(define XK:Thai-topatak 3503)
(define XK:Thai-thothan 3504)
(define XK:Thai-thonangmontho 3505)
(define XK:Thai-thophuthao 3506)
(define XK:Thai-nonen 3507)
(define XK:Thai-dodek 3508)
(define XK:Thai-totao 3509)
(define XK:Thai-thothung 3510)
(define XK:Thai-thothahan 3511)
(define XK:Thai-thothong 3512)
(define XK:Thai-nonu 3513)
(define XK:Thai-bobaimai 3514)
(define XK:Thai-popla 3515)
(define XK:Thai-phophung 3516)
(define XK:Thai-fofa 3517)
(define XK:Thai-phophan 3518)
(define XK:Thai-fofan 3519)
(define XK:Thai-phosamphao 3520)
(define XK:Thai-moma 3521)
(define XK:Thai-yoyak 3522)
(define XK:Thai-rorua 3523)
(define XK:Thai-ru 3524)
(define XK:Thai-loling 3525)
(define XK:Thai-lu 3526)
(define XK:Thai-wowaen 3527)
(define XK:Thai-sosala 3528)
(define XK:Thai-sorusi 3529)
(define XK:Thai-sosua 3530)
(define XK:Thai-hohip 3531)
(define XK:Thai-lochula 3532)
(define XK:Thai-oang 3533)
(define XK:Thai-honokhuk 3534)
(define XK:Thai-paiyannoi 3535)
(define XK:Thai-saraa 3536)
(define XK:Thai-maihanakat 3537)
(define XK:Thai-saraaa 3538)
(define XK:Thai-saraam 3539)
(define XK:Thai-sarai 3540)
(define XK:Thai-saraii 3541)
(define XK:Thai-saraue 3542)
(define XK:Thai-sarauee 3543)
(define XK:Thai-sarau 3544)
(define XK:Thai-sarauu 3545)
(define XK:Thai-phinthu 3546)
(define XK:Thai-maihanakat-maitho 3550)
(define XK:Thai-baht 3551)
(define XK:Thai-sarae 3552)
(define XK:Thai-saraae 3553)
(define XK:Thai-sarao 3554)
(define XK:Thai-saraaimaimuan 3555)
(define XK:Thai-saraaimaimalai 3556)
(define XK:Thai-lakkhangyao 3557)
(define XK:Thai-maiyamok 3558)
(define XK:Thai-maitaikhu 3559)
(define XK:Thai-maiek 3560)
(define XK:Thai-maitho 3561)
(define XK:Thai-maitri 3562)
(define XK:Thai-maichattawa 3563)
(define XK:Thai-thanthakhat 3564)
(define XK:Thai-nikhahit 3565)
(define XK:Thai-leksun 3568)
(define XK:Thai-leknung 3569)
(define XK:Thai-leksong 3570)
(define XK:Thai-leksam 3571)
(define XK:Thai-leksi 3572)
(define XK:Thai-lekha 3573)
(define XK:Thai-lekhok 3574)
(define XK:Thai-lekchet 3575)
(define XK:Thai-lekpaet 3576)
(define XK:Thai-lekkao 3577)
(define XK:Hangul 65329)
(define XK:Hangul-Start 65330)
(define XK:Hangul-End 65331)
(define XK:Hangul-Hanja 65332)
(define XK:Hangul-Jamo 65333)
(define XK:Hangul-Romaja 65334)
(define XK:Hangul-Codeinput 65335)
(define XK:Hangul-Jeonja 65336)
(define XK:Hangul-Banja 65337)
(define XK:Hangul-PreHanja 65338)
(define XK:Hangul-PostHanja 65339)
(define XK:Hangul-SingleCandidate 65340)
(define XK:Hangul-MultipleCandidate 65341)
(define XK:Hangul-PreviousCandidate 65342)
(define XK:Hangul-Special 65343)
(define XK:Hangul-switch 65406)
(define XK:Hangul-Kiyeog 3745)
(define XK:Hangul-SsangKiyeog 3746)
(define XK:Hangul-KiyeogSios 3747)
(define XK:Hangul-Nieun 3748)
(define XK:Hangul-NieunJieuj 3749)
(define XK:Hangul-NieunHieuh 3750)
(define XK:Hangul-Dikeud 3751)
(define XK:Hangul-SsangDikeud 3752)
(define XK:Hangul-Rieul 3753)
(define XK:Hangul-RieulKiyeog 3754)
(define XK:Hangul-RieulMieum 3755)
(define XK:Hangul-RieulPieub 3756)
(define XK:Hangul-RieulSios 3757)
(define XK:Hangul-RieulTieut 3758)
(define XK:Hangul-RieulPhieuf 3759)
(define XK:Hangul-RieulHieuh 3760)
(define XK:Hangul-Mieum 3761)
(define XK:Hangul-Pieub 3762)
(define XK:Hangul-SsangPieub 3763)
(define XK:Hangul-PieubSios 3764)
(define XK:Hangul-Sios 3765)
(define XK:Hangul-SsangSios 3766)
(define XK:Hangul-Ieung 3767)
(define XK:Hangul-Jieuj 3768)
(define XK:Hangul-SsangJieuj 3769)
(define XK:Hangul-Cieuc 3770)
(define XK:Hangul-Khieuq 3771)
(define XK:Hangul-Tieut 3772)
(define XK:Hangul-Phieuf 3773)
(define XK:Hangul-Hieuh 3774)
(define XK:Hangul-A 3775)
(define XK:Hangul-AE 3776)
(define XK:Hangul-YA 3777)
(define XK:Hangul-YAE 3778)
(define XK:Hangul-EO 3779)
(define XK:Hangul-E 3780)
(define XK:Hangul-YEO 3781)
(define XK:Hangul-YE 3782)
(define XK:Hangul-O 3783)
(define XK:Hangul-WA 3784)
(define XK:Hangul-WAE 3785)
(define XK:Hangul-OE 3786)
(define XK:Hangul-YO 3787)
(define XK:Hangul-U 3788)
(define XK:Hangul-WEO 3789)
(define XK:Hangul-WE 3790)
(define XK:Hangul-WI 3791)
(define XK:Hangul-YU 3792)
(define XK:Hangul-EU 3793)
(define XK:Hangul-YI 3794)
(define XK:Hangul-I 3795)
(define XK:Hangul-J-Kiyeog 3796)
(define XK:Hangul-J-SsangKiyeog 3797)
(define XK:Hangul-J-KiyeogSios 3798)
(define XK:Hangul-J-Nieun 3799)
(define XK:Hangul-J-NieunJieuj 3800)
(define XK:Hangul-J-NieunHieuh 3801)
(define XK:Hangul-J-Dikeud 3802)
(define XK:Hangul-J-Rieul 3803)
(define XK:Hangul-J-RieulKiyeog 3804)
(define XK:Hangul-J-RieulMieum 3805)
(define XK:Hangul-J-RieulPieub 3806)
(define XK:Hangul-J-RieulSios 3807)
(define XK:Hangul-J-RieulTieut 3808)
(define XK:Hangul-J-RieulPhieuf 3809)
(define XK:Hangul-J-RieulHieuh 3810)
(define XK:Hangul-J-Mieum 3811)
(define XK:Hangul-J-Pieub 3812)
(define XK:Hangul-J-PieubSios 3813)
(define XK:Hangul-J-Sios 3814)
(define XK:Hangul-J-SsangSios 3815)
(define XK:Hangul-J-Ieung 3816)
(define XK:Hangul-J-Jieuj 3817)
(define XK:Hangul-J-Cieuc 3818)
(define XK:Hangul-J-Khieuq 3819)
(define XK:Hangul-J-Tieut 3820)
(define XK:Hangul-J-Phieuf 3821)
(define XK:Hangul-J-Hieuh 3822)
(define XK:Hangul-RieulYeorinHieuh 3823)
(define XK:Hangul-SunkyeongeumMieum 3824)
(define XK:Hangul-SunkyeongeumPieub 3825)
(define XK:Hangul-PanSios 3826)
(define XK:Hangul-KkogjiDalrinIeung 3827)
(define XK:Hangul-SunkyeongeumPhieuf 3828)
(define XK:Hangul-YeorinHieuh 3829)
(define XK:Hangul-AraeA 3830)
(define XK:Hangul-AraeAE 3831)
(define XK:Hangul-J-PanSios 3832)
(define XK:Hangul-J-KkogjiDalrinIeung 3833)
(define XK:Hangul-J-YeorinHieuh 3834)
(define XK:Korean-Won 3839)
(define XK:Armenian-ligature-ew 16778631)
(define XK:Armenian-full-stop 16778633)
(define XK:Armenian-verjaket 16778633)
(define XK:Armenian-separation-mark 16778589)
(define XK:Armenian-but 16778589)
(define XK:Armenian-hyphen 16778634)
(define XK:Armenian-yentamna 16778634)
(define XK:Armenian-exclam 16778588)
(define XK:Armenian-amanak 16778588)
(define XK:Armenian-accent 16778587)
(define XK:Armenian-shesht 16778587)
(define XK:Armenian-question 16778590)
(define XK:Armenian-paruyk 16778590)
(define XK:Armenian-AYB 16778545)
(define XK:Armenian-ayb 16778593)
(define XK:Armenian-BEN 16778546)
(define XK:Armenian-ben 16778594)
(define XK:Armenian-GIM 16778547)
(define XK:Armenian-gim 16778595)
(define XK:Armenian-DA 16778548)
(define XK:Armenian-da 16778596)
(define XK:Armenian-YECH 16778549)
(define XK:Armenian-yech 16778597)
(define XK:Armenian-ZA 16778550)
(define XK:Armenian-za 16778598)
(define XK:Armenian-E 16778551)
(define XK:Armenian-e 16778599)
(define XK:Armenian-AT 16778552)
(define XK:Armenian-at 16778600)
(define XK:Armenian-TO 16778553)
(define XK:Armenian-to 16778601)
(define XK:Armenian-ZHE 16778554)
(define XK:Armenian-zhe 16778602)
(define XK:Armenian-INI 16778555)
(define XK:Armenian-ini 16778603)
(define XK:Armenian-LYUN 16778556)
(define XK:Armenian-lyun 16778604)
(define XK:Armenian-KHE 16778557)
(define XK:Armenian-khe 16778605)
(define XK:Armenian-TSA 16778558)
(define XK:Armenian-tsa 16778606)
(define XK:Armenian-KEN 16778559)
(define XK:Armenian-ken 16778607)
(define XK:Armenian-HO 16778560)
(define XK:Armenian-ho 16778608)
(define XK:Armenian-DZA 16778561)
(define XK:Armenian-dza 16778609)
(define XK:Armenian-GHAT 16778562)
(define XK:Armenian-ghat 16778610)
(define XK:Armenian-TCHE 16778563)
(define XK:Armenian-tche 16778611)
(define XK:Armenian-MEN 16778564)
(define XK:Armenian-men 16778612)
(define XK:Armenian-HI 16778565)
(define XK:Armenian-hi 16778613)
(define XK:Armenian-NU 16778566)
(define XK:Armenian-nu 16778614)
(define XK:Armenian-SHA 16778567)
(define XK:Armenian-sha 16778615)
(define XK:Armenian-VO 16778568)
(define XK:Armenian-vo 16778616)
(define XK:Armenian-CHA 16778569)
(define XK:Armenian-cha 16778617)
(define XK:Armenian-PE 16778570)
(define XK:Armenian-pe 16778618)
(define XK:Armenian-JE 16778571)
(define XK:Armenian-je 16778619)
(define XK:Armenian-RA 16778572)
(define XK:Armenian-ra 16778620)
(define XK:Armenian-SE 16778573)
(define XK:Armenian-se 16778621)
(define XK:Armenian-VEV 16778574)
(define XK:Armenian-vev 16778622)
(define XK:Armenian-TYUN 16778575)
(define XK:Armenian-tyun 16778623)
(define XK:Armenian-RE 16778576)
(define XK:Armenian-re 16778624)
(define XK:Armenian-TSO 16778577)
(define XK:Armenian-tso 16778625)
(define XK:Armenian-VYUN 16778578)
(define XK:Armenian-vyun 16778626)
(define XK:Armenian-PYUR 16778579)
(define XK:Armenian-pyur 16778627)
(define XK:Armenian-KE 16778580)
(define XK:Armenian-ke 16778628)
(define XK:Armenian-O 16778581)
(define XK:Armenian-o 16778629)
(define XK:Armenian-FE 16778582)
(define XK:Armenian-fe 16778630)
(define XK:Armenian-apostrophe 16778586)
(define XK:Georgian-an 16781520)
(define XK:Georgian-ban 16781521)
(define XK:Georgian-gan 16781522)
(define XK:Georgian-don 16781523)
(define XK:Georgian-en 16781524)
(define XK:Georgian-vin 16781525)
(define XK:Georgian-zen 16781526)
(define XK:Georgian-tan 16781527)
(define XK:Georgian-in 16781528)
(define XK:Georgian-kan 16781529)
(define XK:Georgian-las 16781530)
(define XK:Georgian-man 16781531)
(define XK:Georgian-nar 16781532)
(define XK:Georgian-on 16781533)
(define XK:Georgian-par 16781534)
(define XK:Georgian-zhar 16781535)
(define XK:Georgian-rae 16781536)
(define XK:Georgian-san 16781537)
(define XK:Georgian-tar 16781538)
(define XK:Georgian-un 16781539)
(define XK:Georgian-phar 16781540)
(define XK:Georgian-khar 16781541)
(define XK:Georgian-ghan 16781542)
(define XK:Georgian-qar 16781543)
(define XK:Georgian-shin 16781544)
(define XK:Georgian-chin 16781545)
(define XK:Georgian-can 16781546)
(define XK:Georgian-jil 16781547)
(define XK:Georgian-cil 16781548)
(define XK:Georgian-char 16781549)
(define XK:Georgian-xan 16781550)
(define XK:Georgian-jhan 16781551)
(define XK:Georgian-hae 16781552)
(define XK:Georgian-he 16781553)
(define XK:Georgian-hie 16781554)
(define XK:Georgian-we 16781555)
(define XK:Georgian-har 16781556)
(define XK:Georgian-hoe 16781557)
(define XK:Georgian-fi 16781558)
(define XK:Xabovedot 16785034)
(define XK:Ibreve 16777516)
(define XK:Zstroke 16777653)
(define XK:Gcaron 16777702)
(define XK:Ocaron 16777681)
(define XK:Obarred 16777631)
(define XK:xabovedot 16785035)
(define XK:ibreve 16777517)
(define XK:zstroke 16777654)
(define XK:gcaron 16777703)
(define XK:ocaron 16777682)
(define XK:obarred 16777845)
(define XK:SCHWA 16777615)
(define XK:schwa 16777817)
(define XK:EZH 16777655)
(define XK:ezh 16777874)
(define XK:Lbelowdot 16784950)
(define XK:lbelowdot 16784951)
(define XK:Abelowdot 16785056)
(define XK:abelowdot 16785057)
(define XK:Ahook 16785058)
(define XK:ahook 16785059)
(define XK:Acircumflexacute 16785060)
(define XK:acircumflexacute 16785061)
(define XK:Acircumflexgrave 16785062)
(define XK:acircumflexgrave 16785063)
(define XK:Acircumflexhook 16785064)
(define XK:acircumflexhook 16785065)
(define XK:Acircumflextilde 16785066)
(define XK:acircumflextilde 16785067)
(define XK:Acircumflexbelowdot 16785068)
(define XK:acircumflexbelowdot 16785069)
(define XK:Abreveacute 16785070)
(define XK:abreveacute 16785071)
(define XK:Abrevegrave 16785072)
(define XK:abrevegrave 16785073)
(define XK:Abrevehook 16785074)
(define XK:abrevehook 16785075)
(define XK:Abrevetilde 16785076)
(define XK:abrevetilde 16785077)
(define XK:Abrevebelowdot 16785078)
(define XK:abrevebelowdot 16785079)
(define XK:Ebelowdot 16785080)
(define XK:ebelowdot 16785081)
(define XK:Ehook 16785082)
(define XK:ehook 16785083)
(define XK:Etilde 16785084)
(define XK:etilde 16785085)
(define XK:Ecircumflexacute 16785086)
(define XK:ecircumflexacute 16785087)
(define XK:Ecircumflexgrave 16785088)
(define XK:ecircumflexgrave 16785089)
(define XK:Ecircumflexhook 16785090)
(define XK:ecircumflexhook 16785091)
(define XK:Ecircumflextilde 16785092)
(define XK:ecircumflextilde 16785093)
(define XK:Ecircumflexbelowdot 16785094)
(define XK:ecircumflexbelowdot 16785095)
(define XK:Ihook 16785096)
(define XK:ihook 16785097)
(define XK:Ibelowdot 16785098)
(define XK:ibelowdot 16785099)
(define XK:Obelowdot 16785100)
(define XK:obelowdot 16785101)
(define XK:Ohook 16785102)
(define XK:ohook 16785103)
(define XK:Ocircumflexacute 16785104)
(define XK:ocircumflexacute 16785105)
(define XK:Ocircumflexgrave 16785106)
(define XK:ocircumflexgrave 16785107)
(define XK:Ocircumflexhook 16785108)
(define XK:ocircumflexhook 16785109)
(define XK:Ocircumflextilde 16785110)
(define XK:ocircumflextilde 16785111)
(define XK:Ocircumflexbelowdot 16785112)
(define XK:ocircumflexbelowdot 16785113)
(define XK:Ohornacute 16785114)
(define XK:ohornacute 16785115)
(define XK:Ohorngrave 16785116)
(define XK:ohorngrave 16785117)
(define XK:Ohornhook 16785118)
(define XK:ohornhook 16785119)
(define XK:Ohorntilde 16785120)
(define XK:ohorntilde 16785121)
(define XK:Ohornbelowdot 16785122)
(define XK:ohornbelowdot 16785123)
(define XK:Ubelowdot 16785124)
(define XK:ubelowdot 16785125)
(define XK:Uhook 16785126)
(define XK:uhook 16785127)
(define XK:Uhornacute 16785128)
(define XK:uhornacute 16785129)
(define XK:Uhorngrave 16785130)
(define XK:uhorngrave 16785131)
(define XK:Uhornhook 16785132)
(define XK:uhornhook 16785133)
(define XK:Uhorntilde 16785134)
(define XK:uhorntilde 16785135)
(define XK:Uhornbelowdot 16785136)
(define XK:uhornbelowdot 16785137)
(define XK:Ybelowdot 16785140)
(define XK:ybelowdot 16785141)
(define XK:Yhook 16785142)
(define XK:yhook 16785143)
(define XK:Ytilde 16785144)
(define XK:ytilde 16785145)
(define XK:Ohorn 16777632)
(define XK:ohorn 16777633)
(define XK:Uhorn 16777647)
(define XK:uhorn 16777648)
(define XK:EcuSign 16785568)
(define XK:ColonSign 16785569)
(define XK:CruzeiroSign 16785570)
(define XK:FFrancSign 16785571)
(define XK:LiraSign 16785572)
(define XK:MillSign 16785573)
(define XK:NairaSign 16785574)
(define XK:PesetaSign 16785575)
(define XK:RupeeSign 16785576)
(define XK:WonSign 16785577)
(define XK:NewSheqelSign 16785578)
(define XK:DongSign 16785579)
(define XK:EuroSign 8364)
(define XK:zerosuperior 16785520)
(define XK:foursuperior 16785524)
(define XK:fivesuperior 16785525)
(define XK:sixsuperior 16785526)
(define XK:sevensuperior 16785527)
(define XK:eightsuperior 16785528)
(define XK:ninesuperior 16785529)
(define XK:zerosubscript 16785536)
(define XK:onesubscript 16785537)
(define XK:twosubscript 16785538)
(define XK:threesubscript 16785539)
(define XK:foursubscript 16785540)
(define XK:fivesubscript 16785541)
(define XK:sixsubscript 16785542)
(define XK:sevensubscript 16785543)
(define XK:eightsubscript 16785544)
(define XK:ninesubscript 16785545)
(define XK:partdifferential 16785922)
(define XK:emptyset 16785925)
(define XK:elementof 16785928)
(define XK:notelementof 16785929)
(define XK:containsas 16785931)
(define XK:squareroot 16785946)
(define XK:cuberoot 16785947)
(define XK:fourthroot 16785948)
(define XK:dintegral 16785964)
(define XK:tintegral 16785965)
(define XK:because 16785973)
(define XK:approxeq 16785992)
(define XK:notapproxeq 16785991)
(define XK:notidentical 16786018)
(define XK:stricteq 16786019)
(define XK:braille-dot-1 65521)
(define XK:braille-dot-2 65522)
(define XK:braille-dot-3 65523)
(define XK:braille-dot-4 65524)
(define XK:braille-dot-5 65525)
(define XK:braille-dot-6 65526)
(define XK:braille-dot-7 65527)
(define XK:braille-dot-8 65528)
(define XK:braille-dot-9 65529)
(define XK:braille-dot-10 65530)
(define XK:braille-blank 16787456)
(define XK:braille-dots-1 16787457)
(define XK:braille-dots-2 16787458)
(define XK:braille-dots-12 16787459)
(define XK:braille-dots-3 16787460)
(define XK:braille-dots-13 16787461)
(define XK:braille-dots-23 16787462)
(define XK:braille-dots-123 16787463)
(define XK:braille-dots-4 16787464)
(define XK:braille-dots-14 16787465)
(define XK:braille-dots-24 16787466)
(define XK:braille-dots-124 16787467)
(define XK:braille-dots-34 16787468)
(define XK:braille-dots-134 16787469)
(define XK:braille-dots-234 16787470)
(define XK:braille-dots-1234 16787471)
(define XK:braille-dots-5 16787472)
(define XK:braille-dots-15 16787473)
(define XK:braille-dots-25 16787474)
(define XK:braille-dots-125 16787475)
(define XK:braille-dots-35 16787476)
(define XK:braille-dots-135 16787477)
(define XK:braille-dots-235 16787478)
(define XK:braille-dots-1235 16787479)
(define XK:braille-dots-45 16787480)
(define XK:braille-dots-145 16787481)
(define XK:braille-dots-245 16787482)
(define XK:braille-dots-1245 16787483)
(define XK:braille-dots-345 16787484)
(define XK:braille-dots-1345 16787485)
(define XK:braille-dots-2345 16787486)
(define XK:braille-dots-12345 16787487)
(define XK:braille-dots-6 16787488)
(define XK:braille-dots-16 16787489)
(define XK:braille-dots-26 16787490)
(define XK:braille-dots-126 16787491)
(define XK:braille-dots-36 16787492)
(define XK:braille-dots-136 16787493)
(define XK:braille-dots-236 16787494)
(define XK:braille-dots-1236 16787495)
(define XK:braille-dots-46 16787496)
(define XK:braille-dots-146 16787497)
(define XK:braille-dots-246 16787498)
(define XK:braille-dots-1246 16787499)
(define XK:braille-dots-346 16787500)
(define XK:braille-dots-1346 16787501)
(define XK:braille-dots-2346 16787502)
(define XK:braille-dots-12346 16787503)
(define XK:braille-dots-56 16787504)
(define XK:braille-dots-156 16787505)
(define XK:braille-dots-256 16787506)
(define XK:braille-dots-1256 16787507)
(define XK:braille-dots-356 16787508)
(define XK:braille-dots-1356 16787509)
(define XK:braille-dots-2356 16787510)
(define XK:braille-dots-12356 16787511)
(define XK:braille-dots-456 16787512)
(define XK:braille-dots-1456 16787513)
(define XK:braille-dots-2456 16787514)
(define XK:braille-dots-12456 16787515)
(define XK:braille-dots-3456 16787516)
(define XK:braille-dots-13456 16787517)
(define XK:braille-dots-23456 16787518)
(define XK:braille-dots-123456 16787519)
(define XK:braille-dots-7 16787520)
(define XK:braille-dots-17 16787521)
(define XK:braille-dots-27 16787522)
(define XK:braille-dots-127 16787523)
(define XK:braille-dots-37 16787524)
(define XK:braille-dots-137 16787525)
(define XK:braille-dots-237 16787526)
(define XK:braille-dots-1237 16787527)
(define XK:braille-dots-47 16787528)
(define XK:braille-dots-147 16787529)
(define XK:braille-dots-247 16787530)
(define XK:braille-dots-1247 16787531)
(define XK:braille-dots-347 16787532)
(define XK:braille-dots-1347 16787533)
(define XK:braille-dots-2347 16787534)
(define XK:braille-dots-12347 16787535)
(define XK:braille-dots-57 16787536)
(define XK:braille-dots-157 16787537)
(define XK:braille-dots-257 16787538)
(define XK:braille-dots-1257 16787539)
(define XK:braille-dots-357 16787540)
(define XK:braille-dots-1357 16787541)
(define XK:braille-dots-2357 16787542)
(define XK:braille-dots-12357 16787543)
(define XK:braille-dots-457 16787544)
(define XK:braille-dots-1457 16787545)
(define XK:braille-dots-2457 16787546)
(define XK:braille-dots-12457 16787547)
(define XK:braille-dots-3457 16787548)
(define XK:braille-dots-13457 16787549)
(define XK:braille-dots-23457 16787550)
(define XK:braille-dots-123457 16787551)
(define XK:braille-dots-67 16787552)
(define XK:braille-dots-167 16787553)
(define XK:braille-dots-267 16787554)
(define XK:braille-dots-1267 16787555)
(define XK:braille-dots-367 16787556)
(define XK:braille-dots-1367 16787557)
(define XK:braille-dots-2367 16787558)
(define XK:braille-dots-12367 16787559)
(define XK:braille-dots-467 16787560)
(define XK:braille-dots-1467 16787561)
(define XK:braille-dots-2467 16787562)
(define XK:braille-dots-12467 16787563)
(define XK:braille-dots-3467 16787564)
(define XK:braille-dots-13467 16787565)
(define XK:braille-dots-23467 16787566)
(define XK:braille-dots-123467 16787567)
(define XK:braille-dots-567 16787568)
(define XK:braille-dots-1567 16787569)
(define XK:braille-dots-2567 16787570)
(define XK:braille-dots-12567 16787571)
(define XK:braille-dots-3567 16787572)
(define XK:braille-dots-13567 16787573)
(define XK:braille-dots-23567 16787574)
(define XK:braille-dots-123567 16787575)
(define XK:braille-dots-4567 16787576)
(define XK:braille-dots-14567 16787577)
(define XK:braille-dots-24567 16787578)
(define XK:braille-dots-124567 16787579)
(define XK:braille-dots-34567 16787580)
(define XK:braille-dots-134567 16787581)
(define XK:braille-dots-234567 16787582)
(define XK:braille-dots-1234567 16787583)
(define XK:braille-dots-8 16787584)
(define XK:braille-dots-18 16787585)
(define XK:braille-dots-28 16787586)
(define XK:braille-dots-128 16787587)
(define XK:braille-dots-38 16787588)
(define XK:braille-dots-138 16787589)
(define XK:braille-dots-238 16787590)
(define XK:braille-dots-1238 16787591)
(define XK:braille-dots-48 16787592)
(define XK:braille-dots-148 16787593)
(define XK:braille-dots-248 16787594)
(define XK:braille-dots-1248 16787595)
(define XK:braille-dots-348 16787596)
(define XK:braille-dots-1348 16787597)
(define XK:braille-dots-2348 16787598)
(define XK:braille-dots-12348 16787599)
(define XK:braille-dots-58 16787600)
(define XK:braille-dots-158 16787601)
(define XK:braille-dots-258 16787602)
(define XK:braille-dots-1258 16787603)
(define XK:braille-dots-358 16787604)
(define XK:braille-dots-1358 16787605)
(define XK:braille-dots-2358 16787606)
(define XK:braille-dots-12358 16787607)
(define XK:braille-dots-458 16787608)
(define XK:braille-dots-1458 16787609)
(define XK:braille-dots-2458 16787610)
(define XK:braille-dots-12458 16787611)
(define XK:braille-dots-3458 16787612)
(define XK:braille-dots-13458 16787613)
(define XK:braille-dots-23458 16787614)
(define XK:braille-dots-123458 16787615)
(define XK:braille-dots-68 16787616)
(define XK:braille-dots-168 16787617)
(define XK:braille-dots-268 16787618)
(define XK:braille-dots-1268 16787619)
(define XK:braille-dots-368 16787620)
(define XK:braille-dots-1368 16787621)
(define XK:braille-dots-2368 16787622)
(define XK:braille-dots-12368 16787623)
(define XK:braille-dots-468 16787624)
(define XK:braille-dots-1468 16787625)
(define XK:braille-dots-2468 16787626)
(define XK:braille-dots-12468 16787627)
(define XK:braille-dots-3468 16787628)
(define XK:braille-dots-13468 16787629)
(define XK:braille-dots-23468 16787630)
(define XK:braille-dots-123468 16787631)
(define XK:braille-dots-568 16787632)
(define XK:braille-dots-1568 16787633)
(define XK:braille-dots-2568 16787634)
(define XK:braille-dots-12568 16787635)
(define XK:braille-dots-3568 16787636)
(define XK:braille-dots-13568 16787637)
(define XK:braille-dots-23568 16787638)
(define XK:braille-dots-123568 16787639)
(define XK:braille-dots-4568 16787640)
(define XK:braille-dots-14568 16787641)
(define XK:braille-dots-24568 16787642)
(define XK:braille-dots-124568 16787643)
(define XK:braille-dots-34568 16787644)
(define XK:braille-dots-134568 16787645)
(define XK:braille-dots-234568 16787646)
(define XK:braille-dots-1234568 16787647)
(define XK:braille-dots-78 16787648)
(define XK:braille-dots-178 16787649)
(define XK:braille-dots-278 16787650)
(define XK:braille-dots-1278 16787651)
(define XK:braille-dots-378 16787652)
(define XK:braille-dots-1378 16787653)
(define XK:braille-dots-2378 16787654)
(define XK:braille-dots-12378 16787655)
(define XK:braille-dots-478 16787656)
(define XK:braille-dots-1478 16787657)
(define XK:braille-dots-2478 16787658)
(define XK:braille-dots-12478 16787659)
(define XK:braille-dots-3478 16787660)
(define XK:braille-dots-13478 16787661)
(define XK:braille-dots-23478 16787662)
(define XK:braille-dots-123478 16787663)
(define XK:braille-dots-578 16787664)
(define XK:braille-dots-1578 16787665)
(define XK:braille-dots-2578 16787666)
(define XK:braille-dots-12578 16787667)
(define XK:braille-dots-3578 16787668)
(define XK:braille-dots-13578 16787669)
(define XK:braille-dots-23578 16787670)
(define XK:braille-dots-123578 16787671)
(define XK:braille-dots-4578 16787672)
(define XK:braille-dots-14578 16787673)
(define XK:braille-dots-24578 16787674)
(define XK:braille-dots-124578 16787675)
(define XK:braille-dots-34578 16787676)
(define XK:braille-dots-134578 16787677)
(define XK:braille-dots-234578 16787678)
(define XK:braille-dots-1234578 16787679)
(define XK:braille-dots-678 16787680)
(define XK:braille-dots-1678 16787681)
(define XK:braille-dots-2678 16787682)
(define XK:braille-dots-12678 16787683)
(define XK:braille-dots-3678 16787684)
(define XK:braille-dots-13678 16787685)
(define XK:braille-dots-23678 16787686)
(define XK:braille-dots-123678 16787687)
(define XK:braille-dots-4678 16787688)
(define XK:braille-dots-14678 16787689)
(define XK:braille-dots-24678 16787690)
(define XK:braille-dots-124678 16787691)
(define XK:braille-dots-34678 16787692)
(define XK:braille-dots-134678 16787693)
(define XK:braille-dots-234678 16787694)
(define XK:braille-dots-1234678 16787695)
(define XK:braille-dots-5678 16787696)
(define XK:braille-dots-15678 16787697)
(define XK:braille-dots-25678 16787698)
(define XK:braille-dots-125678 16787699)
(define XK:braille-dots-35678 16787700)
(define XK:braille-dots-135678 16787701)
(define XK:braille-dots-235678 16787702)
(define XK:braille-dots-1235678 16787703)
(define XK:braille-dots-45678 16787704)
(define XK:braille-dots-145678 16787705)
(define XK:braille-dots-245678 16787706)
(define XK:braille-dots-1245678 16787707)
(define XK:braille-dots-345678 16787708)
(define XK:braille-dots-1345678 16787709)
(define XK:braille-dots-2345678 16787710)
(define XK:braille-dots-12345678 16787711)
(define XK:Sinh-ng 16780674)
(define XK:Sinh-h2 16780675)
(define XK:Sinh-a 16780677)
(define XK:Sinh-aa 16780678)
(define XK:Sinh-ae 16780679)
(define XK:Sinh-aee 16780680)
(define XK:Sinh-i 16780681)
(define XK:Sinh-ii 16780682)
(define XK:Sinh-u 16780683)
(define XK:Sinh-uu 16780684)
(define XK:Sinh-ri 16780685)
(define XK:Sinh-rii 16780686)
(define XK:Sinh-lu 16780687)
(define XK:Sinh-luu 16780688)
(define XK:Sinh-e 16780689)
(define XK:Sinh-ee 16780690)
(define XK:Sinh-ai 16780691)
(define XK:Sinh-o 16780692)
(define XK:Sinh-oo 16780693)
(define XK:Sinh-au 16780694)
(define XK:Sinh-ka 16780698)
(define XK:Sinh-kha 16780699)
(define XK:Sinh-ga 16780700)
(define XK:Sinh-gha 16780701)
(define XK:Sinh-ng2 16780702)
(define XK:Sinh-nga 16780703)
(define XK:Sinh-ca 16780704)
(define XK:Sinh-cha 16780705)
(define XK:Sinh-ja 16780706)
(define XK:Sinh-jha 16780707)
(define XK:Sinh-nya 16780708)
(define XK:Sinh-jnya 16780709)
(define XK:Sinh-nja 16780710)
(define XK:Sinh-tta 16780711)
(define XK:Sinh-ttha 16780712)
(define XK:Sinh-dda 16780713)
(define XK:Sinh-ddha 16780714)
(define XK:Sinh-nna 16780715)
(define XK:Sinh-ndda 16780716)
(define XK:Sinh-tha 16780717)
(define XK:Sinh-thha 16780718)
(define XK:Sinh-dha 16780719)
(define XK:Sinh-dhha 16780720)
(define XK:Sinh-na 16780721)
(define XK:Sinh-ndha 16780723)
(define XK:Sinh-pa 16780724)
(define XK:Sinh-pha 16780725)
(define XK:Sinh-ba 16780726)
(define XK:Sinh-bha 16780727)
(define XK:Sinh-ma 16780728)
(define XK:Sinh-mba 16780729)
(define XK:Sinh-ya 16780730)
(define XK:Sinh-ra 16780731)
(define XK:Sinh-la 16780733)
(define XK:Sinh-va 16780736)
(define XK:Sinh-sha 16780737)
(define XK:Sinh-ssha 16780738)
(define XK:Sinh-sa 16780739)
(define XK:Sinh-ha 16780740)
(define XK:Sinh-lla 16780741)
(define XK:Sinh-fa 16780742)
(define XK:Sinh-al 16780746)
(define XK:Sinh-aa2 16780751)
(define XK:Sinh-ae2 16780752)
(define XK:Sinh-aee2 16780753)
(define XK:Sinh-i2 16780754)
(define XK:Sinh-ii2 16780755)
(define XK:Sinh-u2 16780756)
(define XK:Sinh-uu2 16780758)
(define XK:Sinh-ru2 16780760)
(define XK:Sinh-e2 16780761)
(define XK:Sinh-ee2 16780762)
(define XK:Sinh-ai2 16780763)
(define XK:Sinh-o2 16780764)
(define XK:Sinh-oo2 16780765)
(define XK:Sinh-au2 16780766)
(define XK:Sinh-lu2 16780767)
(define XK:Sinh-ruu2 16780786)
(define XK:Sinh-luu2 16780787)
(define XK:Sinh-kunddaliya 16780788)
